==> molo.forms-0.0.2-py2.py3-none-any.whl: molo/forms/tests/constants.py <==
SEGMENT_FORM_DATA = {
    'name': ['test'],
    'status': ['enabled'],
    'type': ['dynamic'],
    'count': ['0'],
    'wagtail_personalisation_timerule_related-TOTAL_FORMS': ['0'],
    'wagtail_personalisation_timerule_related-INITIAL_FORMS': ['0'],
    'wagtail_personalisation_timerule_related-MIN_NUM_FORMS': ['0'],
    'wagtail_personalisation_timerule_related-MAX_NUM_FORMS': ['1000'],
    'wagtail_personalisation_dayrule_related-TOTAL_FORMS': ['0'],
    'wagtail_personalisation_dayrule_related-INITIAL_FORMS': ['0'],
    'wagtail_personalisation_dayrule_related-MIN_NUM_FORMS': ['0'],
    'wagtail_personalisation_dayrule_related-MAX_NUM_FORMS': ['1000'],
    'wagtail_personalisation_referralrule_related-TOTAL_FORMS': ['0'],
    'wagtail_personalisation_referralrule_related-INITIAL_FORMS': ['0'],
    'wagtail_personalisation_referralrule_related-MIN_NUM_FORMS': ['0'],
    'wagtail_personalisation_referralrule_related-MAX_NUM_FORMS': ['1000'],
    'wagtail_personalisation_visitcountrule_related-TOTAL_FORMS': ['0'],
    'wagtail_personalisation_visitcountrule_related-INITIAL_FORMS': ['0'],
    'wagtail_personalisation_visitcountrule_related-MIN_NUM_FORMS': ['0'],
    'wagtail_personalisation_visitcountrule_related-MAX_NUM_FORMS': ['1000'],
    'forms_formsarticletagrule_related-TOTAL_FORMS': ['0'],
    'forms_formsarticletagrule_related-INITIAL_FORMS': ['0'],
    'forms_formsarticletagrule_related-MIN_NUM_FORMS': ['0'],
    'forms_formsarticletagrule_related-MAX_NUM_FORMS': ['1000'],
    'wagtail_personalisation_queryrule_related-TOTAL_FORMS': ['0'],
    'wagtail_personalisation_queryrule_related-INITIAL_FORMS': ['0'],
    'wagtail_personalisation_queryrule_related-MIN_NUM_FORMS': ['0'],
    'wagtail_personalisation_queryrule_related-MAX_NUM_FORMS': ['1000'],
    'wagtail_personalisation_devicerule_related-TOTAL_FORMS': ['0'],
    'wagtail_personalisation_devicerule_related-INITIAL_FORMS': ['0'],
    'wagtail_personalisation_devicerule_related-MIN_NUM_FORMS': ['0'],
    'wagtail_personalisation_devicerule_related-MAX_NUM_FORMS': ['1000'],
    'wagtail_personalisation_userisloggedinrule_related-TOTAL_FORMS': ['0'],
    'wagtail_personalisation_userisloggedinrule_related-INITIAL_FORMS': ['0'],
    'wagtail_personalisation_userisloggedinrule_related-MIN_NUM_FORMS': ['0'],
    'wagtail_personalisation_userisloggedinrule_related-MAX_NUM_FORMS': [
        '1000'],
    'forms_formsubmissiondatarule_related-TOTAL_FORMS': ['0'],
    'forms_formsubmissiondatarule_related-INITIAL_FORMS': ['0'],
    'forms_formsubmissiondatarule_related-MIN_NUM_FORMS': ['0'],
    'forms_formsubmissiondatarule_related-MAX_NUM_FORMS': ['1000'],
    'forms_formresponserule_related-TOTAL_FORMS': ['1'],
    'forms_formresponserule_related-INITIAL_FORMS': ['0'],
    'forms_formresponserule_related-MIN_NUM_FORMS': ['0'],
    'forms_formresponserule_related-MAX_NUM_FORMS': ['1000'],
    'forms_formresponserule_related-0-form': ['11'],
    'forms_formresponserule_related-0-id': [''],
    'forms_formresponserule_related-0-DELETE': [''],
    'forms_groupmembershiprule_related-TOTAL_FORMS': ['0'],
    'forms_groupmembershiprule_related-INITIAL_FORMS': ['0'],
    'forms_groupmembershiprule_related-MIN_NUM_FORMS': ['0'],
    'forms_groupmembershiprule_related-MAX_NUM_FORMS': ['1000'],
    'forms_combinationrule_related-TOTAL_FORMS': ['0'],
    'forms_combinationrule_related-INITIAL_FORMS': ['0'],
    'forms_combinationrule_related-MIN_NUM_FORMS': ['0'],
    'forms_combinationrule_related-MAX_NUM_FORMS': ['1000'],
}

==> molo.forms-0.0.4-py2.py3-none-any.whl: molo/forms/tests/constants.py <==
SEGMENT_FORM_DATA = {
    'name': ['test'],
    'status': ['enabled'],
    'type': ['dynamic'],
    'count': ['0'],
    'wagtail_personalisation_timerule_related-TOTAL_FORMS': ['0'],
    'wagtail_personalisation_timerule_related-INITIAL_FORMS': ['0'],
    'wagtail_personalisation_timerule_related-MIN_NUM_FORMS': ['0'],
    'wagtail_personalisation_timerule_related-MAX_NUM_FORMS': ['1000'],
    'wagtail_personalisation_dayrule_related-TOTAL_FORMS': ['0'],
    'wagtail_personalisation_dayrule_related-INITIAL_FORMS': ['0'],
    'wagtail_personalisation_dayrule_related-MIN_NUM_FORMS': ['0'],
    'wagtail_personalisation_dayrule_related-MAX_NUM_FORMS': ['1000'],
    'wagtail_personalisation_referralrule_related-TOTAL_FORMS': ['0'],
    'wagtail_personalisation_referralrule_related-INITIAL_FORMS': ['0'],
    'wagtail_personalisation_referralrule_related-MIN_NUM_FORMS': ['0'],
    'wagtail_personalisation_referralrule_related-MAX_NUM_FORMS': ['1000'],
    'wagtail_personalisation_visitcountrule_related-TOTAL_FORMS': ['0'],
    'wagtail_personalisation_visitcountrule_related-INITIAL_FORMS': ['0'],
    'wagtail_personalisation_visitcountrule_related-MIN_NUM_FORMS': ['0'],
    'wagtail_personalisation_visitcountrule_related-MAX_NUM_FORMS': ['1000'],
    'forms_formsarticletagrule_related-TOTAL_FORMS': ['0'],
    'forms_formsarticletagrule_related-INITIAL_FORMS': ['0'],
    'forms_formsarticletagrule_related-MIN_NUM_FORMS': ['0'],
    'forms_formsarticletagrule_related-MAX_NUM_FORMS': ['1000'],
    'wagtail_personalisation_queryrule_related-TOTAL_FORMS': ['0'],
    'wagtail_personalisation_queryrule_related-INITIAL_FORMS': ['0'],
    'wagtail_personalisation_queryrule_related-MIN_NUM_FORMS': ['0'],
    'wagtail_personalisation_queryrule_related-MAX_NUM_FORMS': ['1000'],
    'wagtail_personalisation_devicerule_related-TOTAL_FORMS': ['0'],
    'wagtail_personalisation_devicerule_related-INITIAL_FORMS': ['0'],
    'wagtail_personalisation_devicerule_related-MIN_NUM_FORMS': ['0'],
    'wagtail_personalisation_devicerule_related-MAX_NUM_FORMS': ['1000'],
    'wagtail_personalisation_userisloggedinrule_related-TOTAL_FORMS': ['0'],
    'wagtail_personalisation_userisloggedinrule_related-INITIAL_FORMS': ['0'],
    'wagtail_personalisation_userisloggedinrule_related-MIN_NUM_FORMS': ['0'],
    'wagtail_personalisation_userisloggedinrule_related-MAX_NUM_FORMS': [
        '1000'],
    'forms_formsubmissiondatarule_related-TOTAL_FORMS': ['0'],
    'forms_formsubmissiondatarule_related-INITIAL_FORMS': ['0'],
    'forms_formsubmissiondatarule_related-MIN_NUM_FORMS': ['0'],
    'forms_formsubmissiondatarule_related-MAX_NUM_FORMS': ['1000'],
    'forms_formresponserule_related-TOTAL_FORMS': ['1'],
    'forms_formresponserule_related-INITIAL_FORMS': ['0'],
    'forms_formresponserule_related-MIN_NUM_FORMS': ['0'],
    'forms_formresponserule_related-MAX_NUM_FORMS': ['1000'],
    'forms_formresponserule_related-0-form': ['11'],
    'forms_formresponserule_related-0-id': [''],
    'forms_formresponserule_related-0-DELETE': [''],
    'forms_formgroupmembershiprule_related-TOTAL_FORMS': ['0'],
    'forms_formgroupmembershiprule_related-INITIAL_FORMS': ['0'],
    'forms_formgroupmembershiprule_related-MIN_NUM_FORMS': ['0'],
    'forms_formgroupmembershiprule_related-MAX_NUM_FORMS': ['1000'],
    'forms_formcombinationrule_related-TOTAL_FORMS': ['0'],
    'forms_formcombinationrule_related-INITIAL_FORMS': ['0'],
    'forms_formcombinationrule_related-MIN_NUM_FORMS': ['0'],
    'forms_formcombinationrule_related-MAX_NUM_FORMS': ['1000'],
}
